#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2022/5/5 16:53
# @Author  : chenglongping
# @File    : __init__.py.py
from __future__ import unicode_literals
from amaze_dict.amaze_dict import wrap_value

import logging

logger = logging.getLogger(__name__)
